/**
 * Python plugin for Orthanc
 * Copyright (C) 2020-2021 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#include "../PythonHeaderWrapper.h"

void RegisterOrthancSdk(PyObject* module);
PyMethodDef* GetOrthancSdkFunctions();

PyObject* GetOrthancPluginRestOutputType();
PyObject* GetOrthancPluginServerChunkedRequestReaderType();
PyObject* GetOrthancPluginImageType();
PyObject* GetOrthancPluginJobType();
PyObject* GetOrthancPluginWorklistQueryType();
PyObject* GetOrthancPluginStorageAreaType();
PyObject* GetOrthancPluginFindMatcherType();
PyObject* GetOrthancPluginDicomWebNodeType();
PyObject* GetOrthancPluginWorklistAnswersType();
PyObject* GetOrthancPluginFindAnswersType();
PyObject* GetOrthancPluginPeersType();
PyObject* GetOrthancPluginDicomInstanceType();
PyObject* GetOrthancPluginFindQueryType();
